@@ -2,16 +2,16 @@ use std::convert::TryFrom;
 
 use crate::traits::{AssigningShiftingRightMonoid, ModularPartialMagma, Zeroable};
 
-pub const fn are_same<T: ?Sized, U: ?Sized>() -> bool {
-    trait SameTo<U: ?Sized> {
+pub(crate) const fn are_same<T, U>() -> bool {
+    trait SameTo<U> {
         const VALUE: bool;
     }
 
-    impl<T: ?Sized, U: ?Sized> SameTo<U> for T {
+    impl<T, U> SameTo<U> for T {
         default const VALUE: bool = false;
     }
 
-    impl<T: ?Sized> SameTo<T> for T {
+    impl<T> SameTo<T> for T {
         const VALUE: bool = true;
     }
 
@@ -25,7 +25,7 @@ where
 {
     let mut result: usize = 0;
     let mut value = value;
-    while value >= <T as From<u8>>::from(32u8) {
+    while value >= T::from(32u8) {
         result += 6;
         value >>= 6;
     }
@@ -59,13 +59,6 @@ pub(crate) const fn floor_log(value: usize, base: usize) -> Result<usize, &'stat
     }
 }
 
-pub(crate) const fn power(base: usize, exponent: usize) -> usize {
-    match exponent {
-        0 => 1,
-        _ => base * power(base, exponent - 1),
-    }
-}
-
 pub(crate) fn floor_log2<T>(value: T) -> usize
 where
     T: From<u8> + AssigningShiftingRightMonoid<usize> + PartialOrd,
@@ -74,3 +67,10 @@ where
     debug_assert!(!value.is_zero());
     bit_length(value) - 1
 }
+
+pub(crate) const fn power(base: usize, exponent: usize) -> usize {
+    match exponent {
+        0 => 1,
+        _ => base * power(base, exponent - 1),
+    }
+}
